
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.27.0rc1',
    'branch_nick': 'master',
    'revision_id': 'ccb790faff14d832a532674d61cfd445284d8a7e',
    'revno': 11107
}
